@@ -1,4 +1,5 @@
 """Cryptography-related utilities."""
+import shutil
 import subprocess
 from pathlib import Path
 
@@ -8,6 +9,8 @@ def read_gpg_token(p: Path) -> str:
 
     Raise a RuntimeError if the decryption was unsuccessful.
     """
+    if not shutil.which("gpg"):
+        raise RuntimeError("gpg is required but it's not installed.")
 
     proc = subprocess.run(
         ["gpg", "--decrypt", "-q", str(p)], capture_output=True, timeout=3, check=True
